@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V1.1.1-3
+# Application Name - Health Check V1.1.1-5
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -268,21 +268,32 @@ class HelloWindow(QtGui.QMainWindow):
 	def setRed(self):
 		if self.red.isChecked():
 			self.color.setRed(255)
-		else: self.color.setRed(0)
+			self.red.setStyleSheet("QWidget { background-color: #339933 }")
+		else:
+                        self.color.setRed(0)
+                        self.red.setStyleSheet("QWidget { background-color: #006633 }")
+		
 
 		self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
+		
 
 	def setGreen(self):
 		if self.green.isChecked():
 			self.color.setGreen(255)
-		else: self.color.setGreen(0)
+			self.green.setStyleSheet("QWidget { background-color: #339933 }")
+		else:
+                        self.color.setGreen(0)
+                        self.green.setStyleSheet("QWidget { background-color: #006633 }")
 
 		self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
 
 	def setBlue(self):
 		if self.blue.isChecked():
 			self.color.setBlue(255)
-		else: self.color.setBlue(0)
+			self.blue.setStyleSheet("QWidget { background-color: #339933 }")
+		else:
+                        self.color.setBlue(0)
+                        self.blue.setStyleSheet("QWidget { background-color: #006633 }")
 
 		self.square.setStyleSheet("QWidget { background-color: %s }" % self.color.name())
 
@@ -317,6 +328,33 @@ class Ui_MainWindow(object):
 		self.centralwidget = QtGui.QWidget(MainWindow)
 		self.centralwidget.setObjectName("centralwidget")
 
+                app.setStyleSheet("QPushButton {\
+    /* Let's make the size of the button 1,5 times of font size. */\
+    min-height: 1.5em;\
+    /* Font size just 1.*/\
+    font: 1em;\
+    /* Margins so that we get a little space on the left and right. */\
+    margin: 0 10px 0 10px;\
+    /* The font color */ \
+    color: white;\
+    /* Here's the background gradient with start point, end point, \
+       stop percentage and color, stop percentage and color. */\
+    background-color: #006633;\
+    /* We'll round the borders. */\
+    border-style: outset;\
+    /* Round radius will be 3px */\
+    border-radius: 3px;\
+    /* Border is only one pixel */\
+    border-width: 1px;\
+    /* Border color is now set */\
+    border-color: #C4C4C3;\
+}\2010-04-12-Running.gpx\
+/* This is style when button is pressed */\
+QPushButton:pressed {\
+    /* We'll just invert the gradient by changing the colors around. */\
+    background-color: #339933; }")
+                
+
 
 		# Draw the Menubar
 		fremantle = MainWindow.menuBar().addMenu("Update");
@@ -326,6 +364,7 @@ class Ui_MainWindow(object):
 		QtCore.QObject.connect(actb, QtCore.SIGNAL("triggered()"), self.updateTab1)
 		actc = fremantle.addAction("Comms")
 		QtCore.QObject.connect(actc, QtCore.SIGNAL("triggered()"), self.updateTab2)
+
 		#fremantle = MainWindow.menuBar().addMenu("Applications");
 		#MainWindow.menuBar().addSeparator()
 		#actd = fremantle.addAction("Apps")
@@ -336,13 +375,14 @@ class Ui_MainWindow(object):
 		self.tabWidget = QtGui.QTabWidget(self.centralwidget)
 		self.tabWidget.setGeometry(QtCore.QRect(0, 0, 800, 429))
 		self.tabWidget.setStyleSheet("QTabWidget::pane { /* The tab widget frame */\
-     border-top: 0px solid #C2C7CB;\
+     border-top: 0px solid #006633;\
      position: absolute;\
      top: -0.0em;\
  }\
 \
  QTabWidget::tab-bar {\
      alignment: center;\
+     background-color: #FFFFFF;\
  }\
 \
  /* Style the tab using the tab sub-control. Note that\
@@ -350,24 +390,33 @@ class Ui_MainWindow(object):
  QTabBar::tab {\
      background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,\
                                  stop: 0 #006633, stop: 0.4 #006633,\
-                                 stop: 0.5 ##006633, stop: 1.0 #006633);\
-     border: 0px solid #C4C4C3;\
+                                 stop: 0.5 #006633, stop: 1.0 #006633);\
+     border: 2px solid #C4C4C3;\
      border-bottom-color: #C2C7CB; /* same as the pane color */\
-     border-top-left-radius: 2px;\
-     border-top-right-radius: 2px;\
-     min-width: 8ex;\
-     padding: 0px;\
+     border-top-left-radius: 28px;\
+     border-top-right-radius: 28px;\
+     border-bottom-left-radius: 28px;\
+     border-bottom-right-radius: 28px;\
+     min-width: 8px;\
+     padding: 10px;\
+     height:38px;\
+     margin-right:25px;\
+     padding-left:25px;\
  }\
 \
  QTabBar::tab:selected, QTabBar::tab:hover {\
      background: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1,\
-                                 stop: 0 #fafafa, stop: 0.4 #f4f4f4,\
-                                 stop: 0.5 #e7e7e7, stop: 1.0 #fafafa);\
+                                 stop: 0 #339933, stop: 0.4 #339933,\
+                                 stop: 0.5 #339933, stop: 1.0 #339933);\
  }\
 \
  QTabBar::tab:selected {\
-     border-color: #9B9B9B;\
-     border-bottom-color: #C2C7CB; /* same as pane color */")
+     border-color: #006633;\
+     border-bottom-color: #006633; /* same as pane color */\
+\
+ QTabBar::scroller { /* the width of the scroll buttons */\
+         width: 50px;\
+     }")
 		# Set the font size. I've gone for big... very big - so they are finger friendly.
 		font = QtGui.QFont()
 		font.setPointSize(24)
@@ -388,6 +437,16 @@ class Ui_MainWindow(object):
 		self.listWidget.setSizePolicy(QtGui.QSizePolicy.Minimum,QtGui.QSizePolicy.Minimum)
 		self.listWidget.setResizeMode(QtGui.QListView.Adjust)
 		QtCore.QObject.connect(self.listWidget, QtCore.SIGNAL("itemClicked(QListWidgetItem *)"), self.lclicked) 
+                self.listWidget.setStyleSheet("QListView {\
+     show-decoration-selected: 1; /* make the selection span the entire width of the view */\
+ }\
+ QListView::item:selected:!active {\
+     background-color: #339933; }\
+     QListView::item:selected:active {\
+     background-color: #339933;}\
+ QListView {\
+     background-color: #339933;\
+ }")
 
                
 		
@@ -406,6 +465,16 @@ class Ui_MainWindow(object):
 		self.listWidget2.setFont(font)
 		self.listWidget2.setAlternatingRowColors(True)
 		self.listWidget2.setResizeMode(QtGui.QListView.Adjust)
+		self.listWidget2.setStyleSheet("QListView {\
+     show-decoration-selected: 1; /* make the selection span the entire width of the view */\
+ }\
+ QListView::item:selected:!active {\
+     background-color: #339933; }\
+     QListView::item:selected:active {\
+     background-color: #339933;}\
+ QListView {\
+     background-color: #339933;\
+ }")
 
 		# Show the tab and draw contents
 		self.tabWidget.addTab(self.tab_2, "")
@@ -512,7 +581,7 @@ class Ui_MainWindow(object):
 		# box of some sort
 		self.textBrowser = QtGui.QTextBrowser(self.tab_4)
 		self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-		self.textBrowser.setText (" Health Check V1.1.1-3 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec, Rob1n, Lcuk, W00t_ & MohammadAG.\n Many more people have helped by testing and offering support, so Thank You. \n \n April 2010.")
+		self.textBrowser.setText (" Health Check V1.1.1-5 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457 \n\n Thanks to: Mikec, Rob1n, Lcuk, W00t_ & MohammadAG.\n Many more people have helped by testing and offering support, so Thank You. \n \n April 2010.")
 		# Make the font small!!!
 		font = QtGui.QFont()
 		font.setPointSize(20)
@@ -526,6 +595,8 @@ class Ui_MainWindow(object):
 		print "** Run retranslateUi **"
 		self.retranslateUi(MainWindow)
 		#self.updateTab1()
+		self.listWidget.setCurrentRow(1)
+		self.listWidget2.setCurrentRow(1)
 		
 		# Set which tab you want showing on program load
 		print "** Show tab1 (0) **"
@@ -978,7 +1049,24 @@ class Ui_MainWindow(object):
 		#QtGui.QApplication.processEvents()
                 #time.sleep(2.5)
 		#self.listWidget2.addItem("External IP \t\t\t" + ge.strip())
+
+        def updateBluetooth(self):
+                print " ** Starting Bluetooth Service**"
+		#gl = os.popen('/usr/sbin/hciconfig hci0 up').read()
+		#gl = gl.strip()
+		QtGui.QApplication.processEvents()
+                time.sleep(2.0)
+                gl = os.popen('/usr/sbin/hciconfig hci0 | grep BD').read()            
+		s = gl.split(" ")
+                print "**** SHOW LINE****"
+                print gl
+                for words in s:
+                        print "**** word ****"
+                        print words
+		
                 
+		
+                self.listWidget2.addItem("Bluetooth MAC \t\t" + s[2].strip())
 
 	 
 
@@ -1066,7 +1154,6 @@ class Ui_MainWindow(object):
 		b = os.popen(bb)
 		b.close()
  
-		b.close()
 		print " ** Finished LED Patterns **"
 		bus = dbus.SessionBus()
 		proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
@@ -1217,8 +1304,14 @@ class Ui_MainWindow(object):
                 time.sleep(0.1)
                 progress.setValue(90)
 		self.updatenetname()
+		QtGui.QApplication.processEvents()
 		progress.setWindowTitle("Loading Healthcheck - Networks")
-		self.listWidget2.sortItems()
+		progress.setValue(950)
+                self.updateBluetooth()
+                progress.setWindowTitle("Loading Comms- Bluetooth")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
+                self.listWidget2.sortItems()
                 progress.setValue(100)
                 time.sleep(0.1)
                 print " ** Finished tab 2 update **"
@@ -1309,6 +1402,11 @@ class Ui_MainWindow(object):
 		progress.setWindowTitle("Loading Comms- Cell/Phone")
 		QtGui.QApplication.processEvents()
                 time.sleep(0.3)
+                progress.setValue(60)
+                self.updateBluetooth()
+                progress.setWindowTitle("Loading Comms- Bluetooth")
+                QtGui.QApplication.processEvents()
+                time.sleep(0.3)
                 progress.setValue(80)
 		self.updatenetname()
 		progress.setWindowTitle("Loading Comms - Networks")
@@ -1324,12 +1422,12 @@ class Ui_MainWindow(object):
 		
 	# This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
 	def retranslateUi(self, MainWindow):
-		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.1.1-3", None, QtGui.QApplication.UnicodeUTF8))
-		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
-		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
+		MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check V1.1.1-5", None, QtGui.QApplication.UnicodeUTF8))
+		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System ", None, QtGui.QApplication.UnicodeUTF8))
+		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms ", None, QtGui.QApplication.UnicodeUTF8))
 		#self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Apps", None, QtGui.QApplication.UnicodeUTF8))
-		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Tools", None, QtGui.QApplication.UnicodeUTF8))
-		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), QtGui.QApplication.translate("MainWindow", "About", None, QtGui.QApplication.UnicodeUTF8))
+		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Tools ", None, QtGui.QApplication.UnicodeUTF8))
+		self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_4), QtGui.QApplication.translate("MainWindow", "About ", None, QtGui.QApplication.UnicodeUTF8))
 		
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
